{% extends "base.html" %}
{% load i18n sekizai_tags simple_translation_tags multilingual_events_tags %}
{% load cms_tags %}
{% load url from future %}

{% block main %}
<h1>{% trans "Events" %}</h1>

<h2>{% trans "Upcoming" %}</h2>
{% for event in upcoming_events %}
    {% include "multilingual_events/partials/event_item.html" %}
{% empty %}
	<p>{% trans "No upcoming events found." %}</p>
{% endfor %}

<h2>{% trans "Archived" %}</h2>
{% for event in archived_events %}
    {% include "multilingual_events/partials/event_item.html" %}
{% empty %}
	<p>{% trans "No archived events found." %}</p>
{% endfor %}
{% endblock %}
